﻿using System;
using System.Security.Permissions;
using Microsoft.SharePoint;
using Microsoft.SharePoint.Security;
using Microsoft.SharePoint.Utilities;
using Microsoft.SharePoint.Workflow;
using SUGUK.Suggestions.TimerJobs;

namespace SUGUK.Suggestions.EventHandlers.SuggestionsEventReceiver
{
    /// <summary>
    /// List Item Events
    /// </summary>
    public class SuggestionsEventReceiver : SPItemEventReceiver
    {
        /// <summary>
        /// An item was added.
        /// </summary>
        public override void ItemAdded(SPItemEventProperties properties)
        {
            base.ItemAdded(properties);

            ScheduleWorkItem(properties);
        }

        /// <summary>
        /// Schedules the work item.
        /// </summary>
        /// <param name="properties">The properties.</param>
        private void ScheduleWorkItem(SPItemEventProperties properties)
        {
            Guid siteId = properties.SiteId; 
            Guid webId = properties.Web.ID; 
            Guid listId = properties.ListId; 
            int itemId = properties.ListItemId; 
            Guid itemUniqueId = properties.ListItem.UniqueId;
            int currentUserId = properties.CurrentUserId; 
            
            SPSecurity.RunWithElevatedPrivileges(() => 
            { 
                using (SPSite site = new SPSite(siteId)) 
                { 
                    site.AddWorkItem(Guid.NewGuid(), 
                        DateTime.Now.ToUniversalTime(),
                        SuggestionsActivityJobDefinition.WorkItemTypeId, 
                        webId, 
                        listId, 
                        itemId, 
                        true, 
                        itemUniqueId, 
                        itemUniqueId, 
                        currentUserId, 
                        null, 
                        "", 
                        Guid.Empty); 
                } 
            });
        }
    }
}
