using System;
using System.Runtime.InteropServices;
using System.Security.Permissions;
using Microsoft.SharePoint;
using Microsoft.SharePoint.Security;
using Microsoft.SharePoint.Administration;
using SUGUK.Suggestions.TimerJobs;

namespace SUGUK.Suggestions.Features.WebApp_Suggestions
{
    /// <summary>
    /// This class handles events raised during feature activation, deactivation, installation, uninstallation, and upgrade.
    /// </summary>
    /// <remarks>
    /// The GUID attached to this class may be used during packaging and should not be modified.
    /// </remarks>

    [Guid("9ab776f4-b456-4233-a845-cae58d7b53f4")]
    public class WebApp_SuggestionsEventReceiver : SPFeatureReceiver
    {
        public override void FeatureActivated(SPFeatureReceiverProperties properties)
        {
            base.FeatureActivated(properties);
            SPWebApplication webApp = properties.Feature.Parent as SPWebApplication;

            DeleteJobIfExists(webApp);

            foreach (SPServer server in SPFarm.Local.Servers)
            {
                if (server.Role == SPServerRole.Application || server.Role == SPServerRole.SingleServer)
                {
                    SuggestionsActivityJobDefinition activityFeedECMJob = new SuggestionsActivityJobDefinition(SuggestionsActivityFeedConstants.SuggestionsActivityFeedTimerJob, webApp);

                    activityFeedECMJob.Schedule = GetSchedule();
                    activityFeedECMJob.Update();
                }
            }
        }

        public override void FeatureDeactivating(SPFeatureReceiverProperties properties)
        {
            base.FeatureDeactivating(properties);
            SPWebApplication webApp = properties.Feature.Parent as SPWebApplication;
            DeleteJobIfExists(webApp);
        }

        /// <summary>
        /// Gets the schedule.
        /// </summary>
        /// <returns></returns>
        private SPMinuteSchedule GetSchedule()
        {
            SPMinuteSchedule schedule = new SPMinuteSchedule();
            schedule.BeginSecond = 0;
            schedule.EndSecond = 59;
            schedule.Interval = 15;
            return schedule;
        }

        /// <summary>
        /// Deletes the job if exists.
        /// </summary>
        /// <param name="webApp">The web app.</param>
        private void DeleteJobIfExists(SPWebApplication webApp)
        {
            foreach (SPJobDefinition job in webApp.JobDefinitions)
            {
                if (job.Name == SuggestionsActivityFeedConstants.SuggestionsActivityFeedTimerJob)
                {
                    job.Delete();
                    break;
                }
            }
        }
    }
}
